Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3827)

Unified Diff: chrome/browser/chromeos/app_mode/kiosk_app_manager.h

Issue 2382833002: Rename policy::EnterpriseInstallAttributes to chromeos::InstallAttributes. (Closed)
Patch Set: Add missing #includes. Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/chromeos/BUILD.gn ('k') | chrome/browser/chromeos/app_mode/kiosk_app_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chromeos/app_mode/kiosk_app_manager.h
diff --git a/chrome/browser/chromeos/app_mode/kiosk_app_manager.h b/chrome/browser/chromeos/app_mode/kiosk_app_manager.h
index eb731f2bd9dac069f2cccd20cb6c2eb2c098dd06..d97fce3770b7ceb334cefe397d4e800cb3786754 100644
--- a/chrome/browser/chromeos/app_mode/kiosk_app_manager.h
+++ b/chrome/browser/chromeos/app_mode/kiosk_app_manager.h
@@ -17,8 +17,8 @@
#include "base/time/time.h"
#include "chrome/browser/chromeos/app_mode/kiosk_app_data_delegate.h"
#include "chrome/browser/chromeos/extensions/external_cache.h"
-#include "chrome/browser/chromeos/policy/enterprise_install_attributes.h"
#include "chrome/browser/chromeos/settings/cros_settings.h"
+#include "chrome/browser/chromeos/settings/install_attributes.h"
#include "components/signin/core/account_id/account_id.h"
#include "ui/gfx/image/image_skia.h"
@@ -294,13 +294,12 @@ class KioskAppManager : public KioskAppDataDelegate,
const std::string& id,
extensions::ExtensionDownloaderDelegate::Error error) override;
// Callback for EnterpriseInstallAttributes::LockDevice() during
// EnableConsumerModeKiosk() call.
- void OnLockDevice(
- const EnableKioskAutoLaunchCallback& callback,
- policy::EnterpriseInstallAttributes::LockResult result);
+ void OnLockDevice(const EnableKioskAutoLaunchCallback& callback,
+ InstallAttributes::LockResult result);
- // Callback for EnterpriseInstallAttributes::ReadImmutableAttributes() during
+ // Callback for InstallAttributes::ReadImmutableAttributes() during
// GetConsumerKioskModeStatus() call.
void OnReadImmutableAttributes(
const GetConsumerKioskAutoLaunchStatusCallback& callback);
@@ -294,13 +294,12 @@ class KioskAppManager : public KioskAppDataDelegate,
const std::string& id,
extensions::ExtensionDownloaderDelegate::Error error) override;
- // Callback for EnterpriseInstallAttributes::LockDevice() during
+ // Callback for InstallAttributes::LockDevice() during
// EnableConsumerModeKiosk() call.
« no previous file with comments | « chrome/browser/chromeos/BUILD.gn ('k') | chrome/browser/chromeos/app_mode/kiosk_app_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698